Crate jot_note
Source - JotVarietyError
- Errors that can occur during the operation of the
jot CLI application.
- list
- Lists all files in the specified directory and prints them to the console.
- open
- Opens an existing markdown file in the specified
jot_path directory by its title. - scratch
- Appends a message to a scratch file named
_scratch.md in the given directory. - search
- Searches recursively within a given directory for files containing a specific query string.
- write
- Creates a new markdown file in the specified directory and allows the user to edit its contents.